@@ -77,7 +77,8 @@ class BIMNode (GeometryNode):
         
         if getMetaData:
             self.get_metadata_from_ifc_path()
-            self.get_metadata_from_resource()
+            if getResource or self._resource:
+                self.get_metadata_from_resource()
 
 #---------------------PROPERTIES----------------------------
 
@@ -149,8 +150,8 @@ class BIMNode (GeometryNode):
         Returns:
             o3d.geometry.TriangleMesh or None
         """
-        if self.resource is not None and len(self.resource.triangles)>=2:
-            pass
+        if self._resource is not None and len(self._resource.triangles)>=2:
+            return self._resource
         elif self.get_path():
             resource =  o3d.io.read_triangle_mesh(self.path)
             if len(resource.triangles)>2:
@@ -162,7 +163,7 @@ class BIMNode (GeometryNode):
                 self._resource=gt.ifc_to_mesh(ifcElement)
             except:
                 print('mesh=gt.ifc_to_mesh(ifcElement) error')
-        return self.resource  
+        return self._resource  
 
     def get_globalId(self):
         """Returns the ifc globalId (str).
