@@ -186,6 +186,27 @@ class GeometryNode (Node):
         else:
             raise ValueError('Resource must be Open3D.geometry')
 
+    def get_resource(self):
+        """Returns the geometry data in the node. \n
+        If none is present, it will search for the data on drive from path, graphPath, name or subject. 
+
+        Args:
+            1. self (Geometry)\n
+            2. percentage (float,optional): percentage of point cloud to load. Defaults to 1.0 (100%).\n
+
+        Returns:
+            o3d.geometry.PointCloud or None
+        """
+        if self._resource is not None:
+            return self._resource
+        elif self.get_path():
+            if self.path.endswith('pcd'):
+                resource =  o3d.io.read_point_cloud(self.path)
+                self._resource  =resource
+            elif self.path.endswith('e57'):
+                self._resource = gt.e57path_to_pcd(self.path) 
+        return self._resource  
+
     def get_oriented_bounding_box(self)->o3d.geometry.OrientedBoundingBox:
         """Gets the Open3D OrientedBoundingBox of the node from various inputs.
 
