@@ -81,7 +81,8 @@ class PointCloudNode (GeometryNode):
                 pass
             elif self.get_metadata_from_e57_header():
                 pass
-            self.get_metadata_from_resource()                
+            elif getResource or self._resource is not None:
+                self.get_metadata_from_resource()                
 
 #---------------------PROPERTIES----------------------------
 
@@ -139,7 +140,7 @@ class PointCloudNode (GeometryNode):
         Returns:
             o3d.geometry.PointCloud or None
         """
-        if self.resource is not None and len(self.resource.points)>4:
+        if self._resource is not None and len(self._resource.points)>4:
             return self._resource
         elif self.get_path():
             if self.path.endswith('pcd'):
