@@ -1,32 +1,30 @@
 """
 General Basic functions to support other modules
 """
-
-from distutils import extension
-from doctest import testfile
-from fileinput import filename
-import os
-import rdflib
-from rdflib import XSD, Graph,URIRef,Literal,RDF
-import re
-import numpy as np
-import ntpath
 import datetime
-import PIL.Image
-from PIL.ExifTags import GPSTAGS, TAGS
-from typing import List,Tuple
-from warnings import warn
+import ntpath
+import os
+from pathlib import Path, PureWindowsPath
+import re
+import time
+from typing import List
 
+import numpy as np
+import PIL.Image
+import rdflib
+from PIL.ExifTags import GPSTAGS, TAGS
+from rdflib import RDF, XSD, Graph, Literal, URIRef
 
 #### GLOBAL VARIABLES ####
 
 RDF_EXTENSIONS = [".ttl"]
 IMG_EXTENSION = [".jpg", ".png", ".JPG", ".PNG", ".JPEG"]
 MESH_EXTENSION = [".obj",".ply",".fbx" ]
-PCD_EXTENSION = [".pcd", ".e57",".pts", ".ply", '.xml']
+PCD_EXTENSION = [".pcd", ".e57",".pts", ".ply", '.xml','.csv']
 INT_ATTRIBUTES = ['pointCount','faceCount','e57Index'] #'label'
 FLOAT_ATTRIBUTES = ['xResolution','yResolution','imageWidth','imageHeight','focalLength35mm','principalPointU','principalPointV','accuracy']
 LIST_ATTRIBUTES =  ['distortionCoeficients']
+TIME_FORMAT = "%Y-%m-%d %H-%M-%S"
 
 exif = rdflib.Namespace('http://www.w3.org/2003/12/exif/ns#')
 geo=rdflib.Namespace('http://www.opengis.net/ont/geosparql#') #coordinate system information
@@ -41,6 +39,23 @@ ifc=rdflib.Namespace('http://ifcowl.openbimstandards.org/IFC2X3_Final#')
 
 #### BASIC OPERATIONS ####
 
+def time_funtion(func, *args):
+    """Measures how long the functions takes to run and returns the result 
+
+    Args:
+        func (function): The funtion to measure, write without ()
+        *args (Tuple) : The arguments for the funtion, pass as a tuple with a * in front to pass the arguments seperatly
+
+    Returns:
+        object: The result of the function
+    """
+
+    start = time.time()
+    result = func(*args)
+    end = time.time()
+    print("Completed function `" + func.__name__ + "()` in", np.round(end - start,3), "seconds")
+    return result
+
 def get_extension(path:str) -> str:
     """Returns the file extension.\n
     E.g. D://myData//test.txt -> .txt
@@ -107,17 +122,18 @@ def get_list_of_files(directoryPath:str) -> list:
         A list of filepaths
     """
     # names in the given directory 
+    directoryPath = str(directoryPath)
     listOfFile = os.listdir(directoryPath)
     allFiles = list()
     # Iterate over all the entries
     for entry in listOfFile:
         # Create full path
-        fullPath = os.path.join(directoryPath, entry)
+        fullPath = Path(directoryPath) / entry
         # If entry is a directory then get the list of files in this directory 
-        if os.path.isdir(fullPath):
+        if fullPath.is_dir():
             allFiles = allFiles + get_list_of_files(fullPath)
         else:
-            allFiles.append(fullPath)                
+            allFiles.append(fullPath.as_posix())                
     return allFiles
 
 def get_subject_graph(graph:Graph, subject:URIRef = None) -> Graph:
@@ -139,7 +155,8 @@ def get_subject_graph(graph:Graph, subject:URIRef = None) -> Graph:
         #create graph
         newGraph = Graph()
         newGraph += graph.triples((subject, None, None)) 
-        newGraph._set_namespace_manager(graph._get_namespace_manager())
+        newGraph.namespace_manager = graph.namespace_manager
+        #newGraph._set_namespace_manager(graph._get_namespace_manager())
 
         #validate output
         if (len(newGraph) !=0):
@@ -311,7 +328,7 @@ def get_folder(path :str) -> str:
     Returns:
         folderPath (str)
     """
-    return os.path.dirname(os.path.realpath(path))
+    return os.path.dirname(os.path.abspath(path))
 
 def get_timestamp(path : str) -> str:
     """Returns the timestamp ('%Y-%m-%dT%H:%M:%S') from a filepath.
@@ -804,6 +821,19 @@ def validate_string(string:str, replacement ='_') -> str:
     string=prefix+string
     return string
 
+def parse_path(path : str)-> str:
+    """Reads a path and converts it to posix universal styling
+
+    Args:
+        path (str): the input path
+
+    Returns:
+        str: the converted string
+    """
+    if(path):
+        return PureWindowsPath(path).as_posix()
+    return None
+
 def is_float(element) -> bool:
     """Returns True if Python value is a float.
 
@@ -929,6 +959,8 @@ def bind_ontologies(graph : Graph) -> Graph:
     graph.bind('xcr', xcr)
     ifc=rdflib.Namespace('http://ifcowl.openbimstandards.org/IFC2X3_Final#')
     graph.bind('ifc', ifc)
+    loa=rdflib.Namespace('https://docplayer.net/131921614-Usibd-level-of-accuracy-loa-specification-guide.html#')
+    graph.bind('loa', loa)    
     return graph
 
 def clean_attributes_list(list:list) -> list:
@@ -1013,7 +1045,7 @@ def validate_timestamp(value) -> datetime:
     except:
         pass
     try:
-        return datetime.datetime.fromtimestamp(float(string)).strftime('%Y-%m-%dT%H:%M:%S')
+        return datetime.datetime.utcfromtimestamp(float(string)).strftime('%Y-%m-%dT%H:%M:%S')
     except:
         raise ValueError('no valid time formatting found e.g. 1.value (Tue Dec  7 09:38:13 2021) 2.value (1648468136.033126) 3.value (2022:03:13 13:55:30)')
 
