@@ -143,7 +143,7 @@ class TestNode(unittest.TestCase):
         #path1 without getResource
         node= ImageNode(path=self.path1)
         self.assertEqual(node.name,ut.get_filename(self.path1))
-        self.assertIsNone(node.resource)
+        self.assertIsNone(node._resource)
 
         #path2 with getResource
         node= ImageNode(path=self.path2,getResource=True)        
@@ -228,30 +228,30 @@ class TestNode(unittest.TestCase):
     def test_node_creation_with_get_resource(self):
         #mesh
         node= ImageNode(resource=self.img1)
-        self.assertIsNotNone(node.resource)
+        self.assertIsNotNone(node._resource)
 
         #path without getResource
         node= ImageNode(path=self.path2)
-        self.assertIsNone(node.resource)
+        self.assertIsNone(node._resource)
 
         #path with getResource
         node= ImageNode(path=self.path5,getResource=True)
-        self.assertIsNotNone(node.resource)
+        self.assertIsNotNone(node._resource)
 
         #graph with get resource
         node= ImageNode(subject=self.subject2,graph=self.imgGraph,getResource=True)
-        self.assertIsNone(node.resource)
+        self.assertIsNone(node._resource)
         
         #graphPath with get resource
         node= ImageNode(subject=self.subject3,graphPath=self.imgGraphPath,getResource=True)
-        self.assertIsNotNone(node.resource)
+        self.assertIsNotNone(node._resource)
 
     def test_clear_resource(self):
         #mesh
         node= ImageNode(resource=self.img1)
-        self.assertIsNotNone(node.resource)
+        self.assertIsNotNone(node._resource)
         del node.resource
-        self.assertIsNone(node.resource)
+        self.assertIsNone(node._resource)
 
     def test_save_resource(self):
         #no mesh -> False
